'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _joi = require('joi');

var _joi2 = _interopRequireDefault(_joi);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const today = new Date(Date.now()).toISOString().split('T')[0];

const paymentDataSchema = {
	line_identifier: _joi2.default.string().regex(/^[0-9]+$/).required(),
	amount: _joi2.default.number().precision(2).required(),
	net_amount: _joi2.default.number().precision(2).required(),
	tax_amount: _joi2.default.number().precision(2).required(),
	allocated_amount: _joi2.default.number().precision(2).required(),
	tax_code: _joi2.default.string().valid('O').required(),
	tax_rate: _joi2.default.string().valid('0').required(),
	sales_reference: _joi2.default.string().required(),
	product_reference: _joi2.default.string().valid('RoadSidePayments').required(),
	product_description: _joi2.default.string().valid('Fixed Penalties', 'Immobilisation', 'Court Deposits').required(),
	invoice_date: _joi2.default.date().min(today).required(),
	receiver_reference: _joi2.default.string().token().required(),
	receiver_name: _joi2.default.string().valid('DVSA RSP').required(),
	receiver_address: _joi2.default.object().keys({
		line_1: _joi2.default.string().required(),
		line_2: _joi2.default.string().required(),
		line_3: _joi2.default.string().required(),
		line_4: _joi2.default.string().empty(''),
		city: _joi2.default.string().required(),
		postcode: _joi2.default.string().required()
	}),
	rule_start_date: _joi2.default.date().min(today).required(),
	deferment_period: _joi2.default.string().valid('1').required(),
	sales_person_reference: _joi2.default.string().valid('Enforcement', 'Impounding').required(),
	user_id: _joi2.default.string().required()
};

exports.default = {
	request: _joi2.default.object().keys({
		redirect_uri: _joi2.default.string().when('scope', { is: ['CARD', 'CNP'], then: _joi2.default.string().required(), otherwise: _joi2.default.forbidden() }),
		slip_number: _joi2.default.when('scope', { is: ['CASH', 'CHEQUE', 'POSTAL_ORDER'], then: _joi2.default.string().required(), otherwise: _joi2.default.forbidden() }),
		batch_number: _joi2.default.when('scope', { is: ['CASH', 'CHEQUE', 'POSTAL_ORDER'], then: _joi2.default.string().required(), otherwise: _joi2.default.forbidden() }),
		receipt_date: _joi2.default.when('scope', { is: ['CASH', 'CHEQUE', 'POSTAL_ORDER'], then: _joi2.default.string().required(), otherwise: _joi2.default.forbidden() }),
		cheque_date: _joi2.default.when('scope', { is: 'CHEQUE', then: _joi2.default.string().required(), otherwise: _joi2.default.any().forbidden() }),
		cheque_number: _joi2.default.when('scope', { is: 'CHEQUE', then: _joi2.default.string().required(), otherwise: _joi2.default.any().forbidden() }),
		name_on_cheque: _joi2.default.when('scope', { is: 'CHEQUE', then: _joi2.default.string().required(), otherwise: _joi2.default.any().forbidden() }),
		postal_order_number: _joi2.default.when('scope', { is: 'POSTAL_ORDER', then: _joi2.default.string().required(), otherwise: _joi2.default.any().forbidden() }),
		total_amount: _joi2.default.number().integer().min(10).max(9999),
		customer_reference: _joi2.default.string().required(),
		scope: _joi2.default.string().valid('CARD', 'CHEQUE', 'CNP', 'CASH', 'POSTAL_ORDER', 'REPORT', 'CHARGE_BACK', 'CHEQUE_RD').required(),
		country_code: _joi2.default.string().valid('GB').required(),
		customer_manager_name: _joi2.default.string().regex(/^[a-z]+$/).required(),
		customer_name: _joi2.default.string().valid('DVSA RSP').required(),
		customer_address: _joi2.default.object().keys({
			line_1: _joi2.default.string().required(),
			line_2: _joi2.default.string().required(),
			line_3: _joi2.default.string().required(),
			line_4: _joi2.default.string().empty(''),
			city: _joi2.default.string().required(),
			postcode: _joi2.default.string().required()
		}),
		payment_data: _joi2.default.array().items(_joi2.default.object(paymentDataSchema)).min(1).max(10)
	})
};
module.exports = exports['default'];