'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _joi = require('joi');

var _joi2 = _interopRequireDefault(_joi);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const regNoValidation = _joi2.default.string().min(1).max(10).regex(/^[A-Z0-9a-z]{1,10}$/);

const driverSchema = {
	name: _joi2.default.string(),
	address: _joi2.default.string(),
	licenceNumber: _joi2.default.string()
};

const vehicleSchema = {
	regNo: regNoValidation.required(),
	make: _joi2.default.string(),
	nationality: _joi2.default.string()
};

const trailerSchema = {
	number1: _joi2.default.string(),
	number2: _joi2.default.string()
};

const valueSchema = {
	penaltyType: _joi2.default.string().regex(/^(IM|CDN|FPN)$/).required(),
	paymentStatus: _joi2.default.string().valid(['PAID', 'UNPAID']),
	paymentAuthCode: _joi2.default.string().alphanum(),
	// .when('paymentStatus', { is: 'PAID', then: Joi.required() }),
	paymentDate: _joi2.default.number().integer(),
	// .when('paymentStatus', { is: 'PAID', then: Joi.required() }),
	paymentToken: _joi2.default.string().alphanum().required(),
	referenceNo: _joi2.default.string().required().regex(/^[0-9-A-Z]*$/).min(8).max(18),
	driverDetails: _joi2.default.object(driverSchema),
	vehicleDetails: _joi2.default.object(vehicleSchema).required(),
	trailerDetails: _joi2.default.object(trailerSchema),
	nonEndorsableOffence: _joi2.default.array().items(_joi2.default.string()),
	penaltyAmount: _joi2.default.number().integer().required().min(10).max(9999),
	paymentDueDate: _joi2.default.number().integer(),
	officerName: _joi2.default.string().required(),
	dateTime: _joi2.default.number().integer().required(),
	paymentCodeDateTime: _joi2.default.number().integer(),
	placeWhereIssued: _joi2.default.string(),
	officerID: _joi2.default.string().regex(/^[a-zA-Z0-9_-]*$/).required(),
	siteCode: _joi2.default.number().integer().required(),
	inPenaltyGroup: _joi2.default.boolean().required(),
	paymentStartTime: _joi2.default.number()
};

exports.default = {
	request: _joi2.default.object().keys({
		ID: _joi2.default.string().token().required(),
		Hash: _joi2.default.string().required().alphanum(),
		Enabled: _joi2.default.boolean().required(),
		Offset: _joi2.default.number(),
		Value: _joi2.default.object(valueSchema),
		Origin: _joi2.default.string().regex(/^[A-Z]*$/),
		VehicleRegistration: regNoValidation
	})
};
module.exports = exports['default'];