'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _expect = require('expect');

var _expect2 = _interopRequireDefault(_expect);

var _cpmsTransaction = require('./cpmsTransaction');

var _cpmsTransaction2 = _interopRequireDefault(_cpmsTransaction);

var _cpmsPayloadSampleCard = require('../../test/data/cpmsPayloads/cpmsPayloadSampleCard');

var _cpmsPayloadSampleCard2 = _interopRequireDefault(_cpmsPayloadSampleCard);

var _cpmsPayloadSampleCardSingleIm = require('../../test/data/cpmsPayloads/cpmsPayloadSampleCardSingleIm');

var _cpmsPayloadSampleCardSingleIm2 = _interopRequireDefault(_cpmsPayloadSampleCardSingleIm);

var _cpmsPayloadSampleCardNotPresent = require('../../test/data/cpmsPayloads/cpmsPayloadSampleCardNotPresent');

var _cpmsPayloadSampleCardNotPresent2 = _interopRequireDefault(_cpmsPayloadSampleCardNotPresent);

var _cpmsPayloadSampleCash = require('../../test/data/cpmsPayloads/cpmsPayloadSampleCash');

var _cpmsPayloadSampleCash2 = _interopRequireDefault(_cpmsPayloadSampleCash);

var _cpmsPayloadSampleCheque = require('../../test/data/cpmsPayloads/cpmsPayloadSampleCheque');

var _cpmsPayloadSampleCheque2 = _interopRequireDefault(_cpmsPayloadSampleCheque);

var _cpmsPayloadSamplePostal = require('../../test/data/cpmsPayloads/cpmsPayloadSamplePostal');

var _cpmsPayloadSamplePostal2 = _interopRequireDefault(_cpmsPayloadSamplePostal);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('cpmsTransactionValidation', () => {

	context('given exceptional input values are being validated', () => {
		describe('when a blank object is passed for validation', () => {
			it('should return valid set to false', () => {
				const validationResult = (0, _cpmsTransaction2.default)({});
				(0, _expect2.default)(validationResult.valid).toBe(false);
			});
		});

		describe('when null is passed for validation', () => {
			it('should return valid set to false', () => {
				const validationResult = (0, _cpmsTransaction2.default)(null);
				(0, _expect2.default)(validationResult.valid).toBe(false);
			});
		});
	});

	context('given a card payment object is being validated', () => {
		let cardPaymentObject;

		beforeEach(() => {
			cardPaymentObject = _extends({}, _cpmsPayloadSampleCard2.default);
		});

		describe('when a valid payment object is passed for validation', () => {
			it('should return valid set to true', () => {
				const validationResult = (0, _cpmsTransaction2.default)(cardPaymentObject);
				(0, _expect2.default)(validationResult.error.message).toBeUndefined();
				(0, _expect2.default)(validationResult.valid).toBe(true);
			});
		});

		describe('when included payment item doesn\'t match payment item schema', () => {
			it('should return valid set to false', () => {
				delete cardPaymentObject.payment_data[0].sales_reference;
				const validationResult = (0, _cpmsTransaction2.default)(cardPaymentObject);
				(0, _expect2.default)(validationResult.valid).toBe(false);
				(0, _expect2.default)(validationResult.error.message).toContain('sales_reference');
			});
		});

		describe('when payment object array is empty', () => {
			it('should return valid set to false', () => {
				cardPaymentObject.payment_data = [];
				const validationResult = (0, _cpmsTransaction2.default)(cardPaymentObject);
				(0, _expect2.default)(validationResult.valid).toBe(false);
			});
		});

		describe('when card payment object has property from cash payment object', () => {
			it('should return valid set to false', () => {
				cardPaymentObject.slip_number = 'test';
				const validationResult = (0, _cpmsTransaction2.default)(cardPaymentObject);
				(0, _expect2.default)(validationResult.valid).toBe(false);
				(0, _expect2.default)(validationResult.error.message).toContain('slip_number');
			});
		});
	});

	context('given a payment containing an immobilisation is being taken', () => {
		let immobCardPaymentObj;
		beforeEach(() => {
			immobCardPaymentObj = _extends({}, _cpmsPayloadSampleCardSingleIm2.default);
		});

		describe('when a valid payment object is passed for validation', () => {
			it('should return with valid set to true', () => {
				const validationResult = (0, _cpmsTransaction2.default)(immobCardPaymentObj);
				(0, _expect2.default)(validationResult.error.message).toBeUndefined();
				(0, _expect2.default)(validationResult.valid).toBe(true);
			});
		});
	});

	context('given a card not present payment object is being validated', () => {
		let cardNotPresentPaymentObject;

		beforeEach(() => {
			cardNotPresentPaymentObject = _extends({}, _cpmsPayloadSampleCardNotPresent2.default);
		});
		describe('when a valid payment object is passed for validation', () => {
			it('should return valid set to true', () => {
				const validationResult = (0, _cpmsTransaction2.default)(cardNotPresentPaymentObject);
				(0, _expect2.default)(validationResult.error.message).toBeUndefined();
				(0, _expect2.default)(validationResult.valid).toBe(true);
			});
		});
	});

	context('given a cash payment object is being validated', () => {
		let cashPaymentObject;

		beforeEach(() => {
			cashPaymentObject = _extends({}, _cpmsPayloadSampleCash2.default);
		});
		describe('when a valid payment object is passed for validation', () => {
			it('should return valid set to true', () => {
				const validationResult = (0, _cpmsTransaction2.default)(cashPaymentObject);
				(0, _expect2.default)(validationResult.error.message).toBeUndefined();
				(0, _expect2.default)(validationResult.valid).toBe(true);
			});
		});
	});

	context('given a cheque payment object is  being validated', () => {
		let chequePaymentObject;

		beforeEach(() => {
			chequePaymentObject = _extends({}, _cpmsPayloadSampleCheque2.default);
		});
		describe('when a valid cheque payment object is passed for validation', () => {
			it('should return valid set to true', () => {
				const validationResult = (0, _cpmsTransaction2.default)(chequePaymentObject);
				(0, _expect2.default)(validationResult.error.message).toBeUndefined();
				(0, _expect2.default)(validationResult.valid).toBe(true);
			});
		});
	});

	context('given a postal order payment object is being validated', () => {
		let postalOrderPaymentObject;

		beforeEach(() => {
			postalOrderPaymentObject = _extends({}, _cpmsPayloadSamplePostal2.default);
		});
		describe('when a valid postal order payment obejct is passed for validation', () => {
			it('should return valid set to true', () => {
				const validationResult = (0, _cpmsTransaction2.default)(postalOrderPaymentObject);
				(0, _expect2.default)(validationResult.error.message).toBeUndefined();
				(0, _expect2.default)(validationResult.valid).toBe(true);
			});
		});
	});
});