'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _joi = require('joi');

var _joi2 = _interopRequireDefault(_joi);

var _penaltyValidation = require('../ValidationModels/penaltyValidation');

var _penaltyValidation2 = _interopRequireDefault(_penaltyValidation);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = data => {
	const validationResult = _joi2.default.validate(data, _penaltyValidation2.default.request);
	if (validationResult.error) {
		return {
			valid: false,
			error: {
				message: 'Invalid Input'
			}
		};
	}

	// additional validations
	if (data.Value.penaltyType !== 'IM' && data.ID !== `${data.Value.referenceNo}_${data.Value.penaltyType}`) {
		const errMsg = 'ID does not match referenceNo and penaltyType';
		return { valid: false, error: { message: errMsg } };
	}

	if (data.Value.penaltyType !== 'IM' && data.Value.referenceNo.length < 12) {
		const errMsg = 'ReferenceNo is too short';
		return { valid: false, error: { message: errMsg } };
	}

	if (data.Value.penaltyType !== 'IM' && data.Value.referenceNo.length > 13) {
		const errMsg = 'ReferenceNo is too long';
		return { valid: false, error: { message: errMsg } };
	}

	if (data.Value.penaltyType === 'IM') {

		if (!data.Value.referenceNo.match(/^[0-9]{1,6}-[0-9]-[0-9]{1,6}-IM$/)) {
			const errMsg = 'ReferenceNo should be 999999-9-999999-IM format';
			return { valid: false, error: { message: errMsg } };
		}

		const matches = data.Value.referenceNo.match(/^([0-9]{1,6})-([0-1])-([0-9]{1,6})-IM$/);
		if (matches && matches.length > 3) {
			const initialSegment = Number(matches[1]);
			const middleSegment = Number(matches[2]);
			const lastSegment = Number(matches[3]);

			if (initialSegment === 0 || lastSegment === 0 || middleSegment !== 0 && middleSegment !== 1) {
				const errMsg = 'Invalid referenceNo';
				return { valid: false, error: { message: errMsg } };
			}
			const idMatches = data.ID.match(/^([0-9]{6})([0-1])([0-9]{6})_IM$/);

			if (idMatches && idMatches.length > 3) {
				const idInitialSegment = Number(idMatches[1]);
				const idMiddleSegment = Number(idMatches[2]);
				const idLastSegment = Number(idMatches[3]);

				if (idInitialSegment !== initialSegment || idLastSegment !== lastSegment || idMiddleSegment !== middleSegment) {
					const errMsg = 'ID does not match referenceNo and penaltyType';
					return { valid: false, error: { message: errMsg } };
				}
			} else {
				const errMsg = 'Invalid ID';
				return { valid: false, error: { message: errMsg } };
			}
		} else {
			const errMsg = 'Invalid reference No';
			return { valid: false, error: { message: errMsg } };
		}
	}
	return { valid: true, error: {} };
};

module.exports = exports['default'];