'use strict';

var _expect = require('expect');

var _expect2 = _interopRequireDefault(_expect);

var _penaltyGroups = require('./penaltyGroups');

var _penaltyGroups2 = _interopRequireDefault(_penaltyGroups);

var _penaltyGroupSubmissionSample = require('../../test/data/penaltyGroupSubmissionSample');

var _penaltyGroupSubmissionSample2 = _interopRequireDefault(_penaltyGroupSubmissionSample);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('penaltyGroupValidation', () => {
	let penaltyGroup;

	beforeEach(() => {
		penaltyGroup = JSON.parse(JSON.stringify(_penaltyGroupSubmissionSample2.default));
	});

	describe('when a valid penalty group passed for validation', () => {
		it('should return valid set to true', () => {
			const validationResult = (0, _penaltyGroups2.default)(penaltyGroup);
			(0, _expect2.default)(validationResult.error.message).toBeUndefined();
			(0, _expect2.default)(validationResult.valid).toBe(true);
		});
	});

	describe('when a blank object passed for validation', () => {
		it('should return valid set to false', () => {
			const validationResult = (0, _penaltyGroups2.default)({});
			(0, _expect2.default)(validationResult.valid).toBe(false);
		});
	});

	describe('when null passed for validation', () => {
		it('should return valid set to false', () => {
			const validationResult = (0, _penaltyGroups2.default)(null);
			(0, _expect2.default)(validationResult.valid).toBe(false);
		});
	});

	describe('when included penalty doesn\'t match penalty document schema', () => {
		it('should return valid set to false', () => {
			delete penaltyGroup.Penalties[0].ID;
			const validationResult = (0, _penaltyGroups2.default)(penaltyGroup);
			(0, _expect2.default)(validationResult.valid).toBe(false);
		});
	});

	describe('when vehicle registration is invalid', () => {
		it('should return valid set to false', () => {
			penaltyGroup.VehicleRegistration = 'FHB, FHBGH';
			const { valid } = (0, _penaltyGroups2.default)(penaltyGroup);
			(0, _expect2.default)(valid).toBe(false);
		});
	});

	describe('when paymentStartTime is valid', () => {
		it('should pass validation', () => {
			penaltyGroup.fpnPaymentStartTime = 1559572341.039;
			penaltyGroup.imPaymentStartTime = 1559572341.039;
			penaltyGroup.cdnPaymentStartTime = 1559572341.039;
			const retObj = (0, _penaltyGroups2.default)(penaltyGroup);
			(0, _expect2.default)(retObj.valid).toBe(true);
		});
	});
});